pub struct CancelOrder;Trait Implementations
Sourceimpl GraphQLQuery for CancelOrder
impl GraphQLQuery for CancelOrder
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CancelOrder
impl RefUnwindSafe for CancelOrder
impl Send for CancelOrder
impl Sync for CancelOrder
impl Unpin for CancelOrder
impl UnsafeUnpin for CancelOrder
impl UnwindSafe for CancelOrder