pub struct GetAccountOrder;Trait Implementations
Sourceimpl GraphQLQuery for GetAccountOrder
impl GraphQLQuery for GetAccountOrder
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetAccountOrder
impl RefUnwindSafe for GetAccountOrder
impl Send for GetAccountOrder
impl Sync for GetAccountOrder
impl Unpin for GetAccountOrder
impl UnsafeUnpin for GetAccountOrder
impl UnwindSafe for GetAccountOrder