pub struct ListAccountBalances;Trait Implementations
Sourceimpl GraphQLQuery for ListAccountBalances
impl GraphQLQuery for ListAccountBalances
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListAccountBalances
impl RefUnwindSafe for ListAccountBalances
impl Send for ListAccountBalances
impl Sync for ListAccountBalances
impl Unpin for ListAccountBalances
impl UnsafeUnpin for ListAccountBalances
impl UnwindSafe for ListAccountBalances