pub struct ListAccountTrades;Trait Implementations
Sourceimpl GraphQLQuery for ListAccountTrades
impl GraphQLQuery for ListAccountTrades
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListAccountTrades
impl RefUnwindSafe for ListAccountTrades
impl Send for ListAccountTrades
impl Sync for ListAccountTrades
impl Unpin for ListAccountTrades
impl UnsafeUnpin for ListAccountTrades
impl UnwindSafe for ListAccountTrades