pub struct ListCandles;Trait Implementations
Sourceimpl GraphQLQuery for ListCandles
impl GraphQLQuery for ListCandles
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListCandles
impl RefUnwindSafe for ListCandles
impl Send for ListCandles
impl Sync for ListCandles
impl Unpin for ListCandles
impl UnsafeUnpin for ListCandles
impl UnwindSafe for ListCandles