pub struct ListMarkets;Trait Implementations
Sourceimpl GraphQLQuery for ListMarkets
impl GraphQLQuery for ListMarkets
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListMarkets
impl RefUnwindSafe for ListMarkets
impl Send for ListMarkets
impl Sync for ListMarkets
impl Unpin for ListMarkets
impl UnsafeUnpin for ListMarkets
impl UnwindSafe for ListMarkets