pub struct ListTrades;Trait Implementations
Sourceimpl GraphQLQuery for ListTrades
impl GraphQLQuery for ListTrades
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListTrades
impl RefUnwindSafe for ListTrades
impl Send for ListTrades
impl Sync for ListTrades
impl Unpin for ListTrades
impl UnsafeUnpin for ListTrades
impl UnwindSafe for ListTrades