pub struct NewAccountTrades;Trait Implementations
Sourceimpl GraphQLQuery for NewAccountTrades
impl GraphQLQuery for NewAccountTrades
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for NewAccountTrades
impl RefUnwindSafe for NewAccountTrades
impl Send for NewAccountTrades
impl Sync for NewAccountTrades
impl Unpin for NewAccountTrades
impl UnsafeUnpin for NewAccountTrades
impl UnwindSafe for NewAccountTrades