pub struct PlaceMarketOrder;Trait Implementations
Sourceimpl GraphQLQuery for PlaceMarketOrder
impl GraphQLQuery for PlaceMarketOrder
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for PlaceMarketOrder
impl RefUnwindSafe for PlaceMarketOrder
impl Send for PlaceMarketOrder
impl Sync for PlaceMarketOrder
impl Unpin for PlaceMarketOrder
impl UnsafeUnpin for PlaceMarketOrder
impl UnwindSafe for PlaceMarketOrder