pub enum AccountTradeSide {
MAKER,
NONE,
TAKER,
Other(String),
}Variants
MAKER
The requesting account was the maker in this trade
NONE
The requesting account played no role in this trade
TAKER
The requesting account was the taker in this trade
Other(String)