Struct nash_protocol::protocol::cancel_order::CancelOrderRequest [−][src]
Request to cancel a single order in a given market. Note: to prove orders have been canceled, the client must sign and sync nonces on the assets in question.
Fields
order_id: Stringmarket: StringImplementations