pub enum DhFillPoolRequest {
Bitcoin(K1FillPool),
Ethereum(K1FillPool),
NEO(R1FillPool),
}Expand description
DhFillPool requests coordinate between the user’s client and the Nash server to gather a set of shared secret R values. The user sends a list of public ECDSA Points to the Nash server. The server sends back its own list of public Points. Both parties then multply the public point by the secret value to construct the same shared secret value (diffie-hellman). Bitcoin and Ethereum both use the Secp256k1 curve, while NEO users the Secp256r1 curve. While this request type holds both the secret and the public values, only the public values are used in creating the GraphQL request. The secrets are used to process a response. Pool requests will generate N new R values.
Variants
Implementations
Sourceimpl DhFillPoolRequest
impl DhFillPoolRequest
Sourcepub fn make_query(&self) -> QueryBody<Variables>
pub fn make_query(&self) -> QueryBody<Variables>
Build a GraphQL request to get R values for MPC signing. These values can be for
secp256k1 or secp256r1 depending on curve. This sets the state r1 or k1
in the client with the secret values associated with DH, which will be used on
a future request to set_pool
Sourceimpl DhFillPoolRequest
impl DhFillPoolRequest
Sourcepub fn new(chain: Blockchain, size: u32) -> Result<Self>
pub fn new(chain: Blockchain, size: u32) -> Result<Self>
Create a new DhFillPool request for a given blockchain
Sourcepub fn blockchain(&self) -> Blockchain
pub fn blockchain(&self) -> Blockchain
Get blockchain associated with DH request