pub enum ServerPublics {
Bitcoin(Vec<Secp256k1Point>),
Ethereum(Vec<Secp256k1Point>),
NEO(Vec<Secp256r1Point>),
}Expand description
Representation of server public keys that can be generated from a response using the appropriate curve
Variants
Implementations
Sourceimpl ServerPublics
impl ServerPublics
Sourcepub fn from_hexstrings(
chain: Blockchain,
response: &DhFillPoolResponse,
) -> Result<Self>
pub fn from_hexstrings( chain: Blockchain, response: &DhFillPoolResponse, ) -> Result<Self>
Transform a list of strings provided by Nash server into points on the required ECDSA curve.
Sourcepub fn publics_for_k1(&self) -> Result<Vec<Secp256k1Point>>
pub fn publics_for_k1(&self) -> Result<Vec<Secp256k1Point>>
Get k1 values if this wrapper contains them or error
Sourcepub fn publics_for_r1(&self) -> Result<Vec<Secp256r1Point>>
pub fn publics_for_r1(&self) -> Result<Vec<Secp256r1Point>>
Get r1 values if this wrapper contains them or error