pub struct ListMarketsResponse {
pub markets: HashMap<String, Market>,
}Expand description
Contains a HashMap that connects market symbol to Market, which tracks precision data.
Fields
markets: HashMap<String, Market>Trait Implementations
Sourceimpl Clone for ListMarketsResponse
impl Clone for ListMarketsResponse
Sourcefn clone(&self) -> ListMarketsResponse
fn clone(&self) -> ListMarketsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListMarketsResponse
impl Debug for ListMarketsResponse
Sourceimpl TryFrom<ResponseData> for ListMarketsResponse
impl TryFrom<ResponseData> for ListMarketsResponse
Sourcetype Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from(response: ResponseData) -> Result<Self>
fn try_from(response: ResponseData) -> Result<Self>
Performs the conversion.