pub struct DynamicQueryBody {
pub variables: HashMap<String, Value>,
pub query: String,
pub operation_name: &'static str,
}Expand description
The form in which queries are sent over HTTP in most implementations. This will be built using the [GraphQLQuery] trait normally.
Fields
variables: HashMap<String, Value>The values for the variables. They must match those declared in the queries. This should be the Variables struct from the generated module corresponding to the query.
query: StringThe GraphQL query, as a string.
operation_name: &'static strThe GraphQL operation name, as a string.