Struct nash_protocol::protocol::multi_request::MultiRequestConstructor [−][src]
pub struct MultiRequestConstructor<T> {
pub constructors: Vec<T>,
}Expand description
A helper type for constructing blockchain payloads and GraphQL requests
Fields
constructors: Vec<T>Implementations
Create a GraphQL request with everything filled in besides blockchain order payloads and signatures (for both the overall request and blockchain payloads)
Create a GraphQL request with everything filled in besides blockchain order payloads and signatures (for both the overall request and blockchain payloads)