Signer

Struct Signer 

pub struct Signer {
    pub api_keys: ApiKeys,
    /* private fields */
}

Fields

api_keys: ApiKeys

Implementations

Source

impl Signer

pub fn new(key_path: &str) -> Result<Self>

pub fn from_data(secret: &str, session: &str) -> Result<Self>

pub fn sign_canonical_string(&self, request: &str) -> RequestPayloadSignature

Sign GraphQL payload request via payload signing key The output is a hex string where signature has been DER encoded Either implemented with k256 from rustcrypto (pure rust) or secp256k1 (better performance)

pub fn sign_child_key( &self, data: BigInt, chain: Blockchain, ) -> Result<(BigInt, BigInt, String)>

Sign data hashed to BigInt with the MPC child key for the given Blockchain

pub fn child_public_key(&self, chain: Blockchain) -> Result<PublicKey>

Get public key for child key on chain

pub fn request_payload_public_key(&self) -> String

Return public key for payload signing in format expected by the Nash backend service BigInt conversion to hex will strip leading zeros, which Nash backend doesn’t like

pub fn paillier_pk(&self) -> &EncryptionKey

pub fn get_address(&self, chain: Blockchain) -> &str

pub fn get_child_key(&self, chain: Blockchain) -> APIchildkey

pub fn get_remaining_r_vals(&self, chain: &Blockchain) -> u32

Get the current number of available R values for the given chain

pub fn fill_r_vals(&self, chain: Blockchain, n: u32)

Call after filling R values to update tracking