pub enum SubscriptionRequest {
Trades(SubscribeTrades),
Ticker(SubscribeTicker),
Orderbook(SubscribeOrderbook),
AccountTrades(SubscribeAccountTrades),
AccountOrders(SubscribeAccountOrders),
AccountBalances(SubscribeAccountBalances),
}Expand description
Wrapper for all subscription request types supported on Nash. Required only for current version of openlimits subscription logic
Variants
Trades(SubscribeTrades)
Ticker(SubscribeTicker)
Orderbook(SubscribeOrderbook)
AccountTrades(SubscribeAccountTrades)
AccountOrders(SubscribeAccountOrders)
AccountBalances(SubscribeAccountBalances)