pub struct AccountOrdersResponse {
pub orders: Vec<Order>,
}Expand description
Order book updates pushed over a subscription consist of a list of bid orders and a list of ask orders.
Fields
orders: Vec<Order>Trait Implementations
Sourceimpl Clone for AccountOrdersResponse
impl Clone for AccountOrdersResponse
Sourcefn clone(&self) -> AccountOrdersResponse
fn clone(&self) -> AccountOrdersResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AccountOrdersResponse
impl RefUnwindSafe for AccountOrdersResponse
impl Send for AccountOrdersResponse
impl Sync for AccountOrdersResponse
impl Unpin for AccountOrdersResponse
impl UnsafeUnpin for AccountOrdersResponse
impl UnwindSafe for AccountOrdersResponse