pub struct SubscribeOrderbookResponse {
pub last_update_id: i64,
pub update_id: i64,
pub bids: Vec<OrderbookOrder>,
pub asks: Vec<OrderbookOrder>,
}Expand description
Order book updates pushed over a subscription consist of a list of bid orders and a list of ask orders.
Fields
last_update_id: i64update_id: i64bids: Vec<OrderbookOrder>asks: Vec<OrderbookOrder>Trait Implementations
Sourceimpl Clone for SubscribeOrderbookResponse
impl Clone for SubscribeOrderbookResponse
Sourcefn clone(&self) -> SubscribeOrderbookResponse
fn clone(&self) -> SubscribeOrderbookResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubscribeOrderbookResponse
impl Debug for SubscribeOrderbookResponse
Sourceimpl From<SubscribeOrderbookResponse> for OpenLimitsWebSocketMessage
impl From<SubscribeOrderbookResponse> for OpenLimitsWebSocketMessage
Sourcefn from(from: SubscribeOrderbookResponse) -> Self
fn from(from: SubscribeOrderbookResponse) -> Self
Converts to this type from the input type.