Module updated_ticker
nash_
protocol
0.3.0
Module updated_
ticker
Module Items
Structs
In nash_
protocol::
protocol::
subscriptions
nash_protocol
::
protocol
::
subscriptions
Module
updated_
ticker
Structs

Subscribe
Ticker
Subscribe
Ticker
Response
Order book updates pushed over a subscription consist of a list of bid orders and a list of ask orders.