pub enum AssetOrCrosschain {
Asset(Asset),
Crosschain,
}Expand description
An asset in the Ethereum and NEO smart contract protocols is represented either by an asset id or an indicator that the trade is occurring across blockchains.
Variants
Implementations
Sourceimpl AssetOrCrosschain
impl AssetOrCrosschain
Sourcepub fn to_eth_bytes(&self) -> [u8; 2]
pub fn to_eth_bytes(&self) -> [u8; 2]
Convert asset to id in bytes interpretable by the Ethereum
smart contract, or 0xffff if it is a cross-chain asset
Sourcepub fn from_eth_bytes(bytes: [u8; 2]) -> Result<Self>
pub fn from_eth_bytes(bytes: [u8; 2]) -> Result<Self>
Read asset bytes from a protocol payload and convert into an Asset or mark as cross-chain
Sourceimpl AssetOrCrosschain
impl AssetOrCrosschain
Sourcepub fn to_neo_bytes(&self) -> Vec<u8> ⓘ
pub fn to_neo_bytes(&self) -> Vec<u8> ⓘ
Convert asset to id in bytes interpretable by the NEO
smart contract, or 0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF if it is a cross-chain asset
Sourcepub fn from_neo_bytes(bytes: Vec<u8>) -> Result<Self>
pub fn from_neo_bytes(bytes: Vec<u8>) -> Result<Self>
Read asset bytes from a protocol payload and convert into an Asset or mark as cross-chain