pub struct Address { /* private fields */ }Expand description
Ethereum addresses are 20 bytes of data that follow a specific encoding, usually represented by a hex string
Implementations
Sourceimpl Address
impl Address
Sourcepub fn new(s: &str) -> Result<Self>
pub fn new(s: &str) -> Result<Self>
Construct a new address from a string. FIXME: probably not a major issue, but we could consider other validation here as well FIXME: we could take a public key / Secp256k1Point as input (or Secp256r1Point in case of NEO) instead of an address, and convert that point to the blockchain-specific address then. In this way, we would at least ensure that the input represents a valid point on the curve.
Sourcepub fn from_bytes(bytes: [u8; 20]) -> Result<Self>
pub fn from_bytes(bytes: [u8; 20]) -> Result<Self>
Create an address from ETH payload bytes