Asset

Enum Asset 

pub enum Asset {
Show 17 variants ETH, BAT, OMG, USDC, USDT, ZRX, LINK, QNT, RLC, ANT, BTC, NEO, GAS, TRAC, GUNTHY, NNN, NOIA,
}
Assets are the units of value that can be traded in a market We also use this type as a root for encodings for smart contract operations defined in super::sc_payloads

Variants



ETH



BAT



OMG



USDC



USDT



ZRX



QNT



RLC



ANT



BTC



NEO



GAS



TRAC



GUNTHY



NNN



NOIA

Implementations

Source

impl Asset

pub fn to_eth_bytes(&self) -> [u8; 2]

This maps assets onto their representation in the ETH SC protocol. Each asset is represented by two bytes which serve as an identifier

pub fn from_eth_bytes(bytes: [u8; 2]) -> Result<Self>

Given two bytes asset id in ETH payload, return asset

Source

impl Asset

pub fn to_neo_bytes(&self) -> Vec<u8>

This maps assets onto their representation in the NEO SC protocol. Each asset is represented by two bytes which serve as an identifier

pub fn from_neo_bytes(bytes: &[u8; 32]) -> Result<Self>

Given two bytes asset id, return asset

Source

impl Asset

pub fn blockchain(&self) -> Blockchain

Get blockchain associated with a specific asset

pub fn name(&self) -> &'static str

Get asset name as an &str. This name will be compatible with the what Nash’s GraphQL protocol wants

pub fn from_str(asset_str: &str) -> Result<Self>

pub fn assets() -> Vec<Self>

Return list of all supported Asset types

Source

impl Asset

pub fn with_precision(&self, precision: u32) -> AssetofPrecision

Starting with an asset, create a new asset of desired precision.