Nonce

Enum Nonce 

pub enum Nonce {
    Value(u32),
    Crosschain,
}
Nonces are 32 bit integers. They increment over time such that data with lower nonces that has already been observed are rejected by the matching engine and smart contract.

Variants



Value(u32)



Crosschain

Implementations

Source

impl Nonce

pub fn to_be_bytes(&self) -> [u8; 4]

Serialize Nonce for ETH payload as BigEndian bytes

pub fn from_be_bytes(bytes: [u8; 4]) -> Result<Self>

Create a nonce from ETH payload bytes

Source

impl Nonce

pub fn to_le_bytes(&self) -> [u8; 8]

Serialize Nonce for NEO payload as 8 bytes LittleEndian

Source

impl Nonce

pub fn crosschain() -> u32