pub enum Rate {
OrderRate(OrderRate),
MaxOrderRate,
MinOrderRate,
FeeRate(OrderRate),
MaxFeeRate,
MinFeeRate,
}Expand description
The Rate enum describes behavior common to rates/prices.
Variants
Implementations
Sourceimpl Rate
impl Rate
Sourcepub fn to_le_bytes(&self) -> Result<[u8; 8]>
pub fn to_le_bytes(&self) -> Result<[u8; 8]>
Convert any Rate into bytes for encoding in a NEO payload
Sourceimpl Rate
impl Rate
Sourcepub fn to_bigdecimal(&self) -> Result<BigDecimal>
pub fn to_bigdecimal(&self) -> Result<BigDecimal>
Return new bigdecimal inner value based on Rate
pub fn invert_rate(&self, precision: Option<u32>) -> Result<Self>
Sourcepub fn subtract_fee(&self, fee: BigDecimal) -> Result<OrderRate>
pub fn subtract_fee(&self, fee: BigDecimal) -> Result<OrderRate>
Subtract fee from user by adjusting the order rate downwards