pub struct Amount {
pub precision: u32,
pub value: BigDecimal,
}Expand description
Amount encodes the amount of asset being bought or sold in an order It is encoded with a precision that depends on the market and asset being traded. For example, in the ETH/USD market, ETH has a precision of 4. In an A/B market, amount is always in units of A.
Fields
precision: u32value: BigDecimalImplementations
Sourceimpl Amount
impl Amount
Sourcepub fn to_le_bytes(&self) -> Result<[u8; 8]>
pub fn to_le_bytes(&self) -> Result<[u8; 8]>
Serialize Amount to Little Endian bytes for NEO payload creation.
Sourceimpl Amount
impl Amount
Sourcepub fn new(str_num: &str, precision: u32) -> Result<Self>
pub fn new(str_num: &str, precision: u32) -> Result<Self>
Construct a new Amount from string and precision
pub fn from_bigdecimal(value: BigDecimal, precision: u32) -> Self
pub fn to_bigdecimal(&self) -> BigDecimal