AssetofPrecision

Struct AssetofPrecision 

pub struct AssetofPrecision {
    pub asset: Asset,
    pub precision: u32,
}
Assets can potentially have different precisions across markets. This keeps track of what precision we are dealing with

Fields

asset: Assetprecision: u32

Implementations

Source

impl AssetofPrecision

pub fn with_amount(&self, amount_str: &str) -> Result<AssetAmount>

Starting with an asset of some precision, create a new asset that holds a specific amount of value