Module utils

Module utils 

Miscellaneous helper functions

Functions

bigint_to_nash_r
Format Nash MPC r value as hex in the way Nash ME expects
bigint_to_nash_sig
Format BigInt signature values as hex in the way Nash ME expects
convert_at_price
current_time_as_i64
Get current time in millis as an i64 for GraphQL timestamps
decode_hexstr
der_encode_sig
Produce DER encoding in bytes for secp256k1 signature
hash_eth_message
Hash ethereum data with keccak
hash_message
hash_neo_message
Hash NEO message (FIXME: move)
pad_zeros
Pad numerical string with zeros to the desired precision. Required for Nash Me backend