Struct nash_protocol::graphql::ListAccountTrades [−][src]
pub struct ListAccountTrades;Trait Implementations
The shape of the variables expected by the query. This should be a generated struct most of the time.
type ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.
Produce a GraphQL query struct that can be JSON serialized and sent to a GraphQL API.