Struct nash_protocol::protocol::asset_nonces::AssetNoncesRequest [−][src]
pub struct AssetNoncesRequest;Expand description
Retrieve asset nonces from Nash server. Asset nonces increment over time with the property that orders and state signed with older nonces is considered invalid by smart contracts on Ethereum and NEO.
Implementations