Enum nash_protocol::protocol::dh_fill_pool::DhFillPoolRequest[][src]

pub enum DhFillPoolRequest {
    Bitcoin(K1FillPool),
    Ethereum(K1FillPool),
    NEO(R1FillPool),
}
DhFillPool requests coordinate between the user’s client and the Nash server to gather a set of shared secret R values. The user sends a list of public ECDSA Points to the Nash server. The server sends back its own list of public Points. Both parties then multply the public point by the secret value to construct the same shared secret value (diffie-hellman). Bitcoin and Ethereum both use the Secp256k1 curve, while NEO users the Secp256r1 curve. While this request type holds both the secret and the public values, only the public values are used in creating the GraphQL request. The secrets are used to process a response. Pool requests will generate N new R values.

Variants

Bitcoin(K1FillPool)

Tuple Fields of Bitcoin

0: K1FillPool
Ethereum(K1FillPool)

Tuple Fields of Ethereum

0: K1FillPool

Tuple Fields of NEO

0: R1FillPool

Implementations

Build a GraphQL request to get R values for MPC signing. These values can be for secp256k1 or secp256r1 depending on curve. This sets the state r1 or k1 in the client with the secret values associated with DH, which will be used on a future request to set_pool

Create a new DhFillPool request for a given blockchain

Get blockchain associated with DH request