Enum nash_protocol::protocol::dh_fill_pool::ServerPublics [−][src]
pub enum ServerPublics {
Bitcoin(Vec<Secp256k1Point>),
Ethereum(Vec<Secp256k1Point>),
NEO(Vec<Secp256r1Point>),
}Expand description
Representation of server public keys that can be generated from a response using the appropriate curve
Variants
Bitcoin(Vec<Secp256k1Point>)Tuple Fields of Bitcoin
0: Vec<Secp256k1Point>Ethereum(Vec<Secp256k1Point>)Tuple Fields of Ethereum
0: Vec<Secp256k1Point>NEO(Vec<Secp256r1Point>)Tuple Fields of NEO
0: Vec<Secp256r1Point>Implementations
Transform a list of strings provided by Nash server into points on the required ECDSA curve.
Get k1 values if this wrapper contains them or error
Get r1 values if this wrapper contains them or error