Struct nash_protocol::protocol::list_markets::ListMarketsResponse [−][src]
Contains a HashMap that connects market symbol to Market, which tracks precision data.
Fields
markets: HashMap<String, Market>Trait Implementations
type Error = ProtocolError
type Error = ProtocolError
The type returned in the event of a conversion error.
Performs the conversion.