Enum nash_protocol::protocol::sign_states::StateUpdatePayload [−][src]
pub enum StateUpdatePayload {
Eth(StateUpdatePayloadEth),
}Expand description
Representation of state update payload. User signs this payload to confirm the current balance of their account and aggregate previous previous state changes that may have occurred via orders.
Variants