Struct nash_protocol::protocol::sign_states::SignStatesResponse [−][src]
pub struct SignStatesResponse {
pub recycled_orders: Vec<RecycledOrder>,
pub server_signed_states: Vec<ServerSignedData>,
pub states: Vec<ContractBalanceState>,
}Expand description
A call to signStates will return a list of recycled orders, a list of states
that have already been signed by the server, and a list of new states for a
client to sign. When the list of states and recycled_orders is empty, this
means the client has nothing else to sign. This is also used as an optional input
argument when creating a SignStatesRequest, as the function is used both to get
a list of states to sign as well as to submit client signed states.
Fields
recycled_orders: Vec<RecycledOrder>server_signed_states: Vec<ServerSignedData>states: Vec<ContractBalanceState>Implementations
Return true if response data has states for the client to sign