Struct nash_protocol::protocol::Signer [−][src]
pub struct Signer {
pub api_keys: ApiKeys,
// some fields omitted
}Fields
api_keys: ApiKeysImplementations
Sign GraphQL payload request via payload signing key The output is a hex string where signature has been DER encoded Either implemented with k256 from rustcrypto (pure rust) or secp256k1 (better performance)
pub fn sign_child_key(
&self,
data: BigInt,
chain: Blockchain
) -> Result<(BigInt, BigInt, String)>
pub fn sign_child_key(
&self,
data: BigInt,
chain: Blockchain
) -> Result<(BigInt, BigInt, String)>
Sign data hashed to BigInt with the MPC child key for the given Blockchain
Get public key for child key on chain
Return public key for payload signing in format expected by the Nash backend service BigInt conversion to hex will strip leading zeros, which Nash backend doesn’t like
Get the current number of available R values for the given chain
Call after filling R values to update tracking