Module nash_protocol::protocol::subscriptions [−][src]
Modules
Subscription to get new trades
Subscription to get new trades
Subscription to get new trades
Subscription to get new trades
Subscribe to update on the order book
Enums
Wrapper for all subscription request types supported on Nash. Required only for current version of openlimits subscription logic
Wrapper for incoming subscription data supported on Nash. Required only for current version of openlimits subscription logic