Enum nash_protocol::protocol::subscriptions::SubscriptionRequest [−][src]
pub enum SubscriptionRequest {
Trades(SubscribeTrades),
Ticker(SubscribeTicker),
Orderbook(SubscribeOrderbook),
AccountTrades(SubscribeAccountTrades),
AccountOrders(SubscribeAccountOrders),
AccountBalances(SubscribeAccountBalances),
}Expand description
Wrapper for all subscription request types supported on Nash. Required only for current version of openlimits subscription logic
Variants
Trades(SubscribeTrades)Tuple Fields of Trades
Ticker(SubscribeTicker)Tuple Fields of Ticker
Orderbook(SubscribeOrderbook)Tuple Fields of Orderbook
AccountTrades(SubscribeAccountTrades)Tuple Fields of AccountTrades
AccountOrders(SubscribeAccountOrders)Tuple Fields of AccountOrders
AccountBalances(SubscribeAccountBalances)Tuple Fields of AccountBalances