Struct nash_protocol::protocol::subscriptions::updated_orderbook::SubscribeOrderbookResponse [−][src]
pub struct SubscribeOrderbookResponse {
pub last_update_id: i64,
pub update_id: i64,
pub bids: Vec<OrderbookOrder>,
pub asks: Vec<OrderbookOrder>,
}Expand description
Order book updates pushed over a subscription consist of a list of bid orders and a list of ask orders.
Fields
last_update_id: i64update_id: i64bids: Vec<OrderbookOrder>asks: Vec<OrderbookOrder>Trait Implementations
Performs the conversion.