Module nash_protocol::protocol::subscriptions::updated_ticker [−][src]
Structs
Order book updates pushed over a subscription consist of a list of bid orders and a list of ask orders.
Order book updates pushed over a subscription consist of a list of bid orders and a list of ask orders.