Struct nash_protocol::protocol::subscriptions::updated_ticker::SubscribeTickerResponse [−][src]
pub struct SubscribeTickerResponse {
pub id: String,
pub a_volume_24h: BigDecimal,
pub b_volume_24h: BigDecimal,
pub best_ask_price: Option<BigDecimal>,
pub best_bid_price: Option<BigDecimal>,
pub best_ask_amount: Option<BigDecimal>,
pub best_bid_amount: Option<BigDecimal>,
pub high_price_24h: Option<BigDecimal>,
pub last_price: Option<BigDecimal>,
pub low_price_24h: Option<BigDecimal>,
pub price_change_24h: Option<BigDecimal>,
pub market_name: String,
}Expand description
Order book updates pushed over a subscription consist of a list of bid orders and a list of ask orders.
Fields
id: Stringa_volume_24h: BigDecimalb_volume_24h: BigDecimalbest_ask_price: Option<BigDecimal>best_bid_price: Option<BigDecimal>best_ask_amount: Option<BigDecimal>best_bid_amount: Option<BigDecimal>high_price_24h: Option<BigDecimal>last_price: Option<BigDecimal>low_price_24h: Option<BigDecimal>price_change_24h: Option<BigDecimal>market_name: StringTrait Implementations