Types shared across the client and protocol requests
Re-exports
pub use blockchain::eth;pub use blockchain::neo;pub use blockchain::AssetOrCrosschain;pub use blockchain::Prefix;pub use blockchain::PublicKey;pub use self::exchange::AccountTradeSide;pub use self::exchange::Amount;pub use self::exchange::Asset;pub use self::exchange::AssetAmount;pub use self::exchange::AssetofPrecision;pub use self::exchange::Blockchain;pub use self::exchange::BuyOrSell;pub use self::exchange::Candle;pub use self::exchange::CandleInterval;pub use self::exchange::DateTimeRange;pub use self::exchange::Market;pub use self::exchange::Nonce;pub use self::exchange::Order;pub use self::exchange::OrderCancellationPolicy;pub use self::exchange::OrderCancellationReason;pub use self::exchange::OrderRate;pub use self::exchange::OrderStatus;pub use self::exchange::OrderType;pub use self::exchange::OrderbookOrder;pub use self::exchange::Rate;pub use self::exchange::Trade;pub use keys::ApiKeys;
Modules
- blockchain
- Types used across protocol requests for constructing and validating blockchain payload data. Any types specific to an individual protocol request will live in the respective module.
- exchange
- Types used for protocol request inputs (arguments) and outputs. Types
specific to a single protocol request will live within the respetitive
module. For example
protocol::place_order. - keys
- This module manages the
ApiKeystype and its general set of functionality, including parsing keys from a JSON file, signing request payloads, and signing blockchain data with MPC child keys. - market_
pair