Types used across protocol requests for constructing and validating blockchain payload data. Any types specific to an individual protocol request will live in the respective module.
Modules
- btc
- Bitcoin specific types shared across protocol requests
- eth
- Ethereum specific types shared across protocol requests
- neo
- NEO specific types shared across protocol requests
Enums
- Address
- Asset
OrCrosschain - An asset in the Ethereum and NEO smart contract protocols is represented either by an asset id or an indicator that the trade is occurring across blockchains.
- Movement
Type - Wrapper type for the two kinds of movments: deposit and withdrawal
- Prefix
- The type prefix indicates what operation this data represents. This is
encoded by 1 byte in the protocol. For example, a payload representing
the fill order operation has
0x01at the start of the data. These prefixes are the same for both NEO and Ethereum payloads. - Public
Key
Functions
- bigdecimal_
to_ nash_ prec - Convert a bigdecimal to precision expected by the Nash ME Nash ME defines precision as only digits right of decimal point
- bigdecimal_
to_ nash_ u64 - Convert a bigdecimal
numtou64for serialization in the protocol using the precision scheme defined by the Nash ME - nash_
u64_ to_ bigdecimal