Struct nash_protocol::types::blockchain::eth::Address [−][src]
pub struct Address { /* fields omitted */ }Expand description
Ethereum addresses are 20 bytes of data that follow a specific encoding, usually represented by a hex string
Implementations
Construct a new address from a string. FIXME: probably not a major issue, but we could consider other validation here as well FIXME: we could take a public key / Secp256k1Point as input (or Secp256r1Point in case of NEO) instead of an address, and convert that point to the blockchain-specific address then. In this way, we would at least ensure that the input represents a valid point on the curve.