pub enum Asset {
Show 17 variants
ETH,
BAT,
OMG,
USDC,
USDT,
ZRX,
LINK,
QNT,
RLC,
ANT,
BTC,
NEO,
GAS,
TRAC,
GUNTHY,
NNN,
NOIA,
}Expand description
Assets are the units of value that can be traded in a market We also use this type as a root for encodings for smart contract operations defined in super::sc_payloads
Variants
Implementations
Sourceimpl Asset
impl Asset
Sourcepub fn to_eth_bytes(&self) -> [u8; 2]
pub fn to_eth_bytes(&self) -> [u8; 2]
This maps assets onto their representation in the ETH SC protocol. Each asset is represented by two bytes which serve as an identifier
Sourcepub fn from_eth_bytes(bytes: [u8; 2]) -> Result<Self>
pub fn from_eth_bytes(bytes: [u8; 2]) -> Result<Self>
Given two bytes asset id in ETH payload, return asset
Sourceimpl Asset
impl Asset
Sourcepub fn to_neo_bytes(&self) -> Vec<u8> ⓘ
pub fn to_neo_bytes(&self) -> Vec<u8> ⓘ
This maps assets onto their representation in the NEO SC protocol. Each asset is represented by two bytes which serve as an identifier
Sourcepub fn from_neo_bytes(bytes: &[u8; 32]) -> Result<Self>
pub fn from_neo_bytes(bytes: &[u8; 32]) -> Result<Self>
Given two bytes asset id, return asset
Sourceimpl Asset
impl Asset
Sourcepub fn blockchain(&self) -> Blockchain
pub fn blockchain(&self) -> Blockchain
Get blockchain associated with a specific asset
Sourcepub fn name(&self) -> &'static str
pub fn name(&self) -> &'static str
Get asset name as an &str. This name will be compatible with the
what Nash’s GraphQL protocol wants
pub fn from_str(asset_str: &str) -> Result<Self>
Sourceimpl Asset
impl Asset
Sourcepub fn with_precision(&self, precision: u32) -> AssetofPrecision
pub fn with_precision(&self, precision: u32) -> AssetofPrecision
Starting with an asset, create a new asset of desired precision.