pub enum Nonce {
Value(u32),
Crosschain,
}Expand description
Nonces are 32 bit integers. They increment over time such that data with lower nonces that has already been observed are rejected by the matching engine and smart contract.
Variants
Implementations
Sourceimpl Nonce
impl Nonce
Sourcepub fn to_be_bytes(&self) -> [u8; 4]
pub fn to_be_bytes(&self) -> [u8; 4]
Serialize Nonce for ETH payload as BigEndian bytes
Sourcepub fn from_be_bytes(bytes: [u8; 4]) -> Result<Self>
pub fn from_be_bytes(bytes: [u8; 4]) -> Result<Self>
Create a nonce from ETH payload bytes