Rate

Enum Rate 

pub enum Rate {
    OrderRate(OrderRate),
    MaxOrderRate,
    MinOrderRate,
    FeeRate(OrderRate),
    MaxFeeRate,
    MinFeeRate,
}
The Rate enum describes behavior common to rates/prices.

Variants



OrderRate(OrderRate)



MaxOrderRate



MinOrderRate



FeeRate(OrderRate)



MaxFeeRate



MinFeeRate

Implementations

Source

impl Rate

pub fn to_be_bytes( &self, order_precision: u32, fee_precision: u32, ) -> Result<Vec<u8>>

Convert any Rate into bytes for encoding in a Ethereum payload

pub fn from_be_bytes(bytes: [u8; 8]) -> Result<Self>

Create Rate from big endian bytes in Ethereum FillOrder payload

Source

impl Rate

pub fn to_le_bytes(&self) -> Result<[u8; 8]>

Convert any Rate into bytes for encoding in a NEO payload

Source

impl Rate

pub fn to_bigdecimal(&self) -> Result<BigDecimal>

Return new bigdecimal inner value based on Rate

pub fn round(&self, precision: i64) -> Result<Self>

Round in the specified precision.

pub fn invert_rate(&self, precision: Option<u32>) -> Result<Self>

pub fn subtract_fee(&self, fee: BigDecimal) -> Result<OrderRate>

Subtract fee from user by adjusting the order rate downwards