pub struct AssetofPrecision {
pub asset: Asset,
pub precision: u32,
}Expand description
Assets can potentially have different precisions across markets. This keeps track of what precision we are dealing with
Fields
asset: Assetprecision: u32Implementations
Sourceimpl AssetofPrecision
impl AssetofPrecision
Sourcepub fn with_amount(&self, amount_str: &str) -> Result<AssetAmount>
pub fn with_amount(&self, amount_str: &str) -> Result<AssetAmount>
Starting with an asset of some precision, create a new asset that holds a specific amount of value