Miscellaneous helper functions
Functions
- bigint_
to_ nash_ r - Format Nash MPC r value as hex in the way Nash ME expects
- bigint_
to_ nash_ sig - Format BigInt signature values as hex in the way Nash ME expects
- convert_
at_ price - current_
time_ as_ i64 - Get current time in millis as an
i64for GraphQL timestamps - decode_
hexstr - der_
encode_ sig - Produce DER encoding in bytes for secp256k1 signature
- hash_
eth_ message - Hash ethereum data with keccak
- hash_
message - hash_
neo_ message - Hash NEO message (FIXME: move)
- pad_
zeros - Pad numerical string with zeros to the desired precision. Required for Nash Me backend